@@ -63,9 +63,14 @@ if (abs(param["anisoRatio"]-1) <=  10^(-4) ){
 model 
 }
 
+
+
+
+
+
 fillParam = function(param) {
 
-	if(is.numeric(param))
+	if(is.vector(param))
 		param = matrix(param, ncol=length(param), nrow=1,
 				dimnames=list("1", names(param)))
 
@@ -135,13 +140,14 @@ fillParam = function(param) {
 
 	theOrder = c('range','shape','variance','nugget','anisoRatio','anisoAngleRadians')
 	otherParams = setdiff(colnames(param), theOrder)
-	param = param[,c(theOrder, otherParams)]
+	param = param[,c(theOrder, otherParams), drop=FALSE]
 
+	param[is.na(param[, 'range']), 'range'] = 1
+	param[is.na(param[, 'anisoRatio']), 'anisoRatio'] = 1
+	param[is.na(param[, 'anisoAngleRadians']), 'anisoAngleRadians'] = 1
+	param[is.na(param[, 'anisoAngleDegrees']), 'anisoAngleDegrees'] = 1
+	
 	param = drop(param)
-	if(is.na(param['range'])) param['range'] = 1
-	if(is.na(param['anisoRatio'])) param['anisoRatio'] = 1
-
-	if(is.na(param['anisoAngleDegrees'])) 
-		param['anisoAngleRadians'] = param['anisoAngleDegrees'] =0
+	
 	param
 }
